#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 opentelemetry
version:              0.8.0
visibility:           public
id:                   opentelemetry-0.8.0-Cx478Fg6C8v3qnQCvzsnvk
key:                  opentelemetry-0.8.0-Cx478Fg6C8v3qnQCvzsnvk
license:              Apache-2.0
maintainer:           ethercrow@gmail.com
author:               Dmitry Ivanov
description:          The OpenTelemetry Haskell Client https://opentelemetry.io
category:             OpenTelemetry
abi:                  8cf4b84e771ca35ec8366b02d784ec4a
exposed:              True
exposed-modules:
    OpenTelemetry.Eventlog OpenTelemetry.Eventlog_Internal
    OpenTelemetry.Metrics_Internal OpenTelemetry.Propagation
    OpenTelemetry.SpanContext

import-dirs:          /usr/lib/ghc-9.6.6/site-local/opentelemetry-0.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/opentelemetry-0.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/opentelemetry-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-opentelemetry
hs-libraries:         HSopentelemetry-0.8.0-Cx478Fg6C8v3qnQCvzsnvk
depends:
    base-4.18.2.1 bytestring-0.11.5.3 exceptions-0.10.7
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    hashable-1.4.7.0-DjTaTzSxyhZLemTcoX34jw

haddock-interfaces:
    /usr/share/doc/haskell-opentelemetry/html/opentelemetry.haddock

haddock-html:         /usr/share/doc/haskell-opentelemetry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

